summaryrefslogtreecommitdiff
path: root/docs/shared_bindings_matrix.py
diff options
context:
space:
mode:
Diffstat (limited to 'docs/shared_bindings_matrix.py')
-rw-r--r--docs/shared_bindings_matrix.py21
1 files changed, 9 insertions, 12 deletions
diff --git a/docs/shared_bindings_matrix.py b/docs/shared_bindings_matrix.py
index e327d6ec6..aa5ef02e2 100644
--- a/docs/shared_bindings_matrix.py
+++ b/docs/shared_bindings_matrix.py
@@ -26,7 +26,7 @@ import os
import re
-SUPPORTED_PORTS = ["atmel-samd", "nrf", "mimxrt10xx"]
+SUPPORTED_PORTS = ["atmel-samd", "nrf", "stm", "mimxrt10xx"]
def parse_port_config(contents, chip_keyword=None):
@@ -98,7 +98,7 @@ def build_module_map():
for module in modules:
full_name = module
search_name = module.lstrip("_")
- re_pattern = "CIRCUITPY_{}\s=\s(.+)".format(search_name.upper())
+ re_pattern = "CIRCUITPY_{}\s*\??=\s*(.+)".format(search_name.upper())
find_config = re.findall(re_pattern, configs)
if not find_config:
continue
@@ -139,7 +139,10 @@ def get_excluded_boards(base):
re_board_chip = re.compile("CHIP_FAMILY\s=\s(\w+)")
chip_keyword = "CHIP_FAMILY"
elif port in ["nrf"]:
- re_board_chip = re.compile("MCU_VARIANT\s=\s(\w+)")
+ re_board_chip = re.compile(r"MCU_VARIANT\s=\s(\w+)")
+ elif port in ["stm"]:
+ re_board_chip = re.compile(r"MCU_SERIES\s*=\s*(\w+)")
+ chip_keyword = "MCU_SERIES"
port_dir = "ports/{}".format(port)
@@ -158,10 +161,10 @@ def get_excluded_boards(base):
contents = board.read()
board_chip = re_board_chip.search(contents)
- #print(entry.name, board_chip.group(1))
if not board_chip:
board_chip = "Unknown Chip"
else:
+ #print(entry.name, board_chip.group(1))
board_chip = board_chip.group(1)
# add port_config results to contents
@@ -172,18 +175,12 @@ def get_excluded_boards(base):
check_dependent_modules = dict()
for module in modules:
board_is_excluded = False
# check if board uses `SMALL_BUILD`. if yes, and current
# module is marked as `FULL_BUILD`, board is excluded
- small_build = re.search("CIRCUITPY_SMALL_BUILD = 1", contents)
+ small_build = re.search("CIRCUITPY_FULL_BUILD = 0", contents)
if small_build and base[module]["full_build"] == "1":
board_is_excluded = True
- # check if board uses `MINIMAL_BUILD`. if yes, and current
- # module is marked as `DEFAULT_BUILD`, board is excluded
- min_build = re.search("CIRCUITPY_MINIMAL_BUILD = 1", contents)
- if min_build and base[module]["default_value"] == "CIRCUITPY_DEFAULT_BUILD":
- board_is_excluded = True
-
# check if module is specifically disabled for this board
re_pattern = r"CIRCUITPY_{}\s=\s(\w)".format(module.upper())
find_module = re.search(re_pattern, contents)
@@ -172,18 +175,12 @@ def get_excluded_boards(base):
for module in modules:
board_is_excluded = False
- # check if board uses `SMALL_BUILD`. if yes, and current
+ # check if board turns off `FULL_BUILD`. if yes, and current
# module is marked as `FULL_BUILD`, board is excluded